@@ -15,6 +15,9 @@ Loads INI files. Example:
     
     [Controller::Foo]
     foo=bar
+    
+    [Model::Baz]
+    qux=xyzzy
 
 =head1 METHODS
 
